#!/bin/sh
#  Author:    Rodney Summerscales, Steven Brown
#  Update:    $Id: runcnc.sh,v 1.2 2006/04/25 17:34:20 sbrown Exp $ 
#  Purpose:   Start cnc10 & handle cnc10 exit codes
#  Usage:     runcnc.sh [--mill] [--lathe] [--help]
#  Note:      This script replaces cnc7m4.bat & cnc7t4.bat
# Copyright (c) 2004 Centroid, Inc. all rights reserved

# define cnc10 exit codes
CAMEXIT=62
NORMALEXIT=66
POWEROFFEXIT=68
CHECKSUMFAILS=10

# check usage
if [ "$1" = "--mill" -a $# -eq 1 ]
then
  # run mill version
  CNC10EXEC=cnc10m.exe
  CNC10CMD=cnc10m4
  CNC10DIR=/cncroot/c/cnc10
else
  if [ "$1" = "--lathe" -a $# -eq 1 ]
  then
    # run lathe version
    CNC10EXEC=cnc10t.exe
    CNC10CMD=cnc10t4
    CNC10DIR=/cncroot/c/cnc10t
  else 
    # display usage
    echo "Usage: runcnc.sh  OPTION"
    echo "Options:"
    echo "   --mill    start cnc10 mill"
    echo "   --lathe   start cnc10 lathe"
    echo "   --help    display usage"
    exit 0
  fi
fi

EXITCODE=$CAMEXIT

# detect floppy drives
AWK_DETECT_FLOPPY_DRIVES='/^Floppy drive/ { print $3 " " $6 }'
export DETECTED_FLOPPY_DRIVES=`dmesg | awk "$AWK_DETECT_FLOPPY_DRIVES"`

# run cnc10 
while [ $EXITCODE -eq $CAMEXIT ]
do
  # Check if cnc10 is already running
  # (for now do not allow more than one instance of cnc10 to be running)
  CNC10PID=`pidof "$CNC10EXEC"`
  if [ $? -eq 0 ]
  then
    echo "$CNC10EXEC is already running!"
    exit 1
  fi

  # Go to correct cnc10 dir
  cd $CNC10DIR

  # Check if specified version of cnc10 is available
  if [ ! -r "bin/$CNC10EXEC" ]
  then
    echo "Error: Cannot find $CNC10EXEC!"
    exit 2
  fi

  # perform checksum on cnc10 exe and hex files
  checksum.sh md5  > checksum.out
  if [ $? -ne 0 ] 
  then
    cat checksum.out                           > cnc10.err
    echo "Error: Checksum failed"              >> cnc10.err
    echo "One or more CNC10 files are corrupt" >> cnc10.err
    EXITCODE=$CHECKSUMFAILS
  else    
    # start cnc10
    $CNC10EXEC > cnc10.err 2>&1
    # remember exit code
    EXITCODE=$?
  fi
  # append any errors to end of msg_log.txt
  cat cnc10.err >> msg_log.txt

  # handle cam exit code 
  if [ $EXITCODE -eq $CAMEXIT ] 
  then
    sh cnc10cam.sh
  fi
done

# handle cnc10 exit code
if [ $EXITCODE -eq $POWEROFFEXIT ]
then
  echo Control is powering down...
  poweroff
else
  if [ $EXITCODE -ne $NORMALEXIT ]
  then 
    echo >> cnc10.err
    echo "Please report this error to your dealer" >> cnc10.err
    echo >> cnc10.err
    STARTMENU_OPTIONS="--error"
  else
    echo >> cnc10.err
    echo "CNC10 has exited normally" >> cnc10.err
    STARTMENU_OPTIONS=
  fi
  echo >> cnc10.err
  echo "*******************************" >> cnc10.err
  # launch start menu
  startmenu cnc10.err $STARTMENU_OPTIONS &
fi
